package logic

import (
	"fusenapi/utils/basic"
	"fusenapi/utils/email"
	"net/http"
	"strings"

	"context"

	"fusenapi/server/ldap-admin/internal/svc"
	"fusenapi/server/ldap-admin/internal/types"

	"github.com/zeromicro/go-zero/core/logx"
)

type AddLdapOrganizationMemberLogic struct {
	logx.Logger
	ctx    context.Context
	svcCtx *svc.ServiceContext
}

func NewAddLdapOrganizationMemberLogic(ctx context.Context, svcCtx *svc.ServiceContext) *AddLdapOrganizationMemberLogic {
	return &AddLdapOrganizationMemberLogic{
		Logger: logx.WithContext(ctx),
		ctx:    ctx,
		svcCtx: svcCtx,
	}
}

// 处理进入前逻辑w,r
// func (l *AddLdapOrganizationMemberLogic) BeforeLogic(w http.ResponseWriter, r *http.Request) {
// }

func (l *AddLdapOrganizationMemberLogic) AddLdapOrganizationMember(req *types.AddLdapOrganizationMemberReq, r *http.Request) (resp *basic.Response) {

	if !l.svcCtx.Ldap.VerifyAuthority(r, l.svcCtx.Config.Auth.AccessSecret) {
		return resp.SetStatusWithMessage(basic.CodeUnAuth, "无权限，请联系管理员开通")
	}
	req.OrganizationDN = strings.Trim(req.OrganizationDN, " ")
	req.UserDN = strings.Trim(req.UserDN, " ")
	if len(req.OrganizationDN) <= 3 || req.OrganizationDN[:3] != "ou=" {
		return resp.SetStatusWithMessage(basic.CodeRequestParamsErr, "参数错误，无效的目标组织DN")
	}
	if len(req.UserDN) <= 3 || req.UserDN[:3] != "cn=" {
		return resp.SetStatusWithMessage(basic.CodeRequestParamsErr, "无效的用户DN")
	}
	cnEmail := strings.Split(req.UserDN, ",")[0][3:]
	if !email.IsEmailValid(cnEmail) {
		return resp.SetStatusWithMessage(basic.CodeRequestParamsErr, "错误的用户cn")
	}
	err := l.svcCtx.Ldap.AddUserToOrganization(req.OrganizationDN, req.UserDN)
	if err != nil {
		logx.Error(err)
		return resp.SetStatusWithMessage(basic.CodeServiceErr, "添加成员失败，"+err.Error())
	}
	return resp.SetStatusWithMessage(basic.CodeOK, "添加成功")
}

// 处理逻辑后 w,r 如:重定向, resp 必须重新处理
// func (l *AddLdapOrganizationMemberLogic) AfterLogic(w http.ResponseWriter, r *http.Request, resp *basic.Response) {
// // httpx.OkJsonCtx(r.Context(), w, resp)
// }
