package logic

import (
	"errors"
	"fusenapi/model/gmodel"
	"fusenapi/utils/auth"
	"fusenapi/utils/basic"

	"context"

	"fusenapi/server/ldap-admin/internal/svc"
	"fusenapi/server/ldap-admin/internal/types"

	"github.com/zeromicro/go-zero/core/logx"
	"gorm.io/gorm"
)

type SetLdapGroupUserLogic struct {
	logx.Logger
	ctx    context.Context
	svcCtx *svc.ServiceContext
}

func NewSetLdapGroupUserLogic(ctx context.Context, svcCtx *svc.ServiceContext) *SetLdapGroupUserLogic {
	return &SetLdapGroupUserLogic{
		Logger: logx.WithContext(ctx),
		ctx:    ctx,
		svcCtx: svcCtx,
	}
}

// 处理进入前逻辑w,r
// func (l *SetLdapGroupUserLogic) BeforeLogic(w http.ResponseWriter, r *http.Request) {
// }

func (l *SetLdapGroupUserLogic) SetLdapGroupUser(req *types.SetLdapGroupUserReq, userinfo *auth.UserInfo) (resp *basic.Response) {
	// 返回值必须调用Set重新返回, resp可以空指针调用 resp.SetStatus(basic.CodeOK, data)
	// userinfo 传入值时, 一定不为null
	resLdapGroupInfo, err := l.svcCtx.AllModels.LdapGroup.FindOneById(l.ctx, req.GroupId)
	if err != nil {
		if errors.Is(err, gorm.ErrRecordNotFound) {
			basic.CodeServiceErr.Message = "权限组记录不存在"
		} else {
			basic.CodeServiceErr.Message = "系统出错"
		}
		return resp.SetStatus(basic.CodeServiceErr)
	}
	resCreateInBatches := l.svcCtx.MysqlConn.WithContext(l.ctx).Create(gmodel.LdapUserGroup{
		GroupId: &resLdapGroupInfo.Id,
		UserId:  &req.UserId,
	})
	if resCreateInBatches.Error != nil {
		basic.CodeServiceErr.Message = "系统出错"
		return resp.SetStatus(basic.CodeServiceErr)
	}
	return resp.SetStatus(basic.CodeOK)
}

// 处理逻辑后 w,r 如:重定向, resp 必须重新处理
// func (l *SetLdapGroupUserLogic) AfterLogic(w http.ResponseWriter, r *http.Request, resp *basic.Response) {
// // httpx.OkJsonCtx(r.Context(), w, resp)
// }
